# Rafnix

Rafnix is a Python library for disease prediction based on symptoms using machine learning.

## Installation

To install the library, use pip:

```bash
pip install rafnix

## Usage

Import the library:

from rafnix import predict_disease

Predict disease:

data = [age, fever, cough, headache, fatigue, diarrhea, sneezing, body_ache, nausea, vomiting]
result = predict_disease(data)
print(f"Predicted illness: {result}")

"# rafnix" 
